@@ -28,5 +28,5 @@ void               html_engine_capitalize_word                   (HTMLEngine
 void               html_engine_upcase_downcase_word              (HTMLEngine       *e,
 								  gboolean          up);
 void               html_engine_set_link                          (HTMLEngine       *e,
-								  const char       *complete_url);
+								  const gchar       *complete_url);
 #endif
